==> ansible-11.1.0.tgz: lib/python3.11/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_vpn_ipsec_fec.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_vpn_ipsec_fec
short_description: Configure Forward Error Correction
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.1.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    state:
        description: The directive to create, update or delete an object.
        type: str
        required: true
        choices:
          - present
          - absent
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    adom:
        description: The parameter (adom) in requested url.
        type: str
        required: true
    vpn_ipsec_fec:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            mappings:
                type: list
                elements: dict
                description: Mappings.
                suboptions:
                    bandwidth_bi_threshold:
                        aliases: ['bandwidth-bi-threshold']
                        type: int
                        description: Apply FEC parameters when available bi-bandwidth is >= threshold
                    bandwidth_down_threshold:
                        aliases: ['bandwidth-down-threshold']
                        type: int
                        description: Apply FEC parameters when available down bandwidth is >= threshold
                    bandwidth_up_threshold:
                        aliases: ['bandwidth-up-threshold']
                        type: int
                        description: Apply FEC parameters when available up bandwidth is >= threshold
                    base:
                        type: int
                        description: Number of base FEC packets
                    latency_threshold:
                        aliases: ['latency-threshold']
                        type: int
                        description: Apply FEC parameters when latency is
                    packet_loss_threshold:
                        aliases: ['packet-loss-threshold']
                        type: int
                        description: Apply FEC parameters when packet loss is >= threshold
                    redundant:
                        type: int
                        description: Number of redundant FEC packets
                    seqno:
                        type: int
                        description: Sequence number
            name:
                type: str
                description: Profile name.
                required: true
'''

EXAMPLES = '''
- name: Example playbook (generated based on argument schema)
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Configure Forward Error Correction
      fortinet.fortimanager.fmgr_vpn_ipsec_fec:
        # bypass_validation: false
        workspace_locking_adom: <value in [global, custom adom including root]>
        workspace_locking_timeout: 300
        # rc_succeeded: [0, -2, -3, ...]
        # rc_failed: [-2, -3, ...]
        adom: <your own value>
        state: present # <value in [present, absent]>
        vpn_ipsec_fec:
          mappings:
            -
              bandwidth_bi_threshold: <integer>
              bandwidth_down_threshold: <integer>
              bandwidth_up_threshold: <integer>
              base: <integer>
              latency_threshold: <integer>
              packet_loss_threshold: <integer>
              redundant: <integer>
              seqno: <integer>
          name: <string>
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    urls_list = [
        '/pm/config/adom/{adom}/obj/vpn/ipsec/fec',
        '/pm/config/global/obj/vpn/ipsec/fec'
    ]
    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'adom': {'required': True, 'type': 'str'},
        'vpn_ipsec_fec': {
            'type': 'dict',
            'v_range': [['7.2.0', '']],
            'options': {
                'mappings': {
                    'v_range': [['7.2.0', '']],
                    'type': 'list',
                    'options': {
                        'bandwidth-bi-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'bandwidth-down-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'bandwidth-up-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'base': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'latency-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'packet-loss-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'redundant': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'seqno': {'v_range': [['7.2.0', '']], 'type': 'int'}
                    },
                    'elements': 'dict'
                },
                'name': {'v_range': [['7.2.0', '']], 'required': True, 'type': 'str'}
            }
        }
    }

    module_option_spec = get_module_arg_spec('full crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'vpn_ipsec_fec'),
                           supports_check_mode=True)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
                       module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_crud()

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()

==> ansible-11.4.0.tgz: lib/python3.12/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_vpn_ipsec_fec.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_vpn_ipsec_fec
short_description: Configure Forward Error Correction
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.1.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    state:
        description: The directive to create, update or delete an object.
        type: str
        required: true
        choices:
          - present
          - absent
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    adom:
        description: The parameter (adom) in requested url.
        type: str
        required: true
    vpn_ipsec_fec:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            mappings:
                type: list
                elements: dict
                description: Mappings.
                suboptions:
                    bandwidth_bi_threshold:
                        aliases: ['bandwidth-bi-threshold']
                        type: int
                        description: Apply FEC parameters when available bi-bandwidth is >= threshold
                    bandwidth_down_threshold:
                        aliases: ['bandwidth-down-threshold']
                        type: int
                        description: Apply FEC parameters when available down bandwidth is >= threshold
                    bandwidth_up_threshold:
                        aliases: ['bandwidth-up-threshold']
                        type: int
                        description: Apply FEC parameters when available up bandwidth is >= threshold
                    base:
                        type: int
                        description: Number of base FEC packets
                    latency_threshold:
                        aliases: ['latency-threshold']
                        type: int
                        description: Apply FEC parameters when latency is
                    packet_loss_threshold:
                        aliases: ['packet-loss-threshold']
                        type: int
                        description: Apply FEC parameters when packet loss is >= threshold
                    redundant:
                        type: int
                        description: Number of redundant FEC packets
                    seqno:
                        type: int
                        description: Sequence number
            name:
                type: str
                description: Profile name.
                required: true
'''

EXAMPLES = '''
- name: Example playbook (generated based on argument schema)
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Configure Forward Error Correction
      fortinet.fortimanager.fmgr_vpn_ipsec_fec:
        # bypass_validation: false
        workspace_locking_adom: <value in [global, custom adom including root]>
        workspace_locking_timeout: 300
        # rc_succeeded: [0, -2, -3, ...]
        # rc_failed: [-2, -3, ...]
        adom: <your own value>
        state: present # <value in [present, absent]>
        vpn_ipsec_fec:
          name: "your value" # Required variable, string
          # mappings:
          #   - bandwidth_bi_threshold: <integer>
          #     bandwidth_down_threshold: <integer>
          #     bandwidth_up_threshold: <integer>
          #     base: <integer>
          #     latency_threshold: <integer>
          #     packet_loss_threshold: <integer>
          #     redundant: <integer>
          #     seqno: <integer>
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    urls_list = [
        '/pm/config/adom/{adom}/obj/vpn/ipsec/fec',
        '/pm/config/global/obj/vpn/ipsec/fec'
    ]
    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'adom': {'required': True, 'type': 'str'},
        'vpn_ipsec_fec': {
            'type': 'dict',
            'v_range': [['7.2.0', '']],
            'options': {
                'mappings': {
                    'v_range': [['7.2.0', '']],
                    'type': 'list',
                    'options': {
                        'bandwidth-bi-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'bandwidth-down-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'bandwidth-up-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'base': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'latency-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'packet-loss-threshold': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'redundant': {'v_range': [['7.2.0', '']], 'type': 'int'},
                        'seqno': {'v_range': [['7.2.0', '']], 'type': 'int'}
                    },
                    'elements': 'dict'
                },
                'name': {'v_range': [['7.2.0', '']], 'required': True, 'type': 'str'}
            }
        }
    }

    module_option_spec = get_module_arg_spec('full crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'vpn_ipsec_fec'),
                           supports_check_mode=True)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
                       module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_crud()

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()
